==> aecu.core-1.1.0-sources.jar: de/valtech/aecu/core/groovy/console/bindings/provider/AecuStarImportExtensionProvider.java <==
/*
 * Copyright 2018 Valtech GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.valtech.aecu.core.groovy.console.bindings.provider;

import com.icfolson.aem.groovy.console.api.StarImportExtensionProvider;
import com.icfolson.aem.groovy.console.constants.GroovyConsoleConstants;

import org.osgi.service.component.annotations.Component;

import java.util.Set;

@Component(immediate = true)
public class AecuStarImportExtensionProvider implements StarImportExtensionProvider {

    @Override
    public Set<String> getStarImports() {
        Set<String> imports = GroovyConsoleConstants.DEFAULT_STAR_IMPORTS;
        imports.add("de.valtech.aecu.core.groovy.console.bindings.filters");
        return imports;
    }
}

==> aecu.core-1.2.0-sources.jar: de/valtech/aecu/core/groovy/console/bindings/provider/AecuStarImportExtensionProvider.java <==
/*
 * Copyright 2018 Valtech GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.valtech.aecu.core.groovy.console.bindings.provider;

import java.util.Set;

import org.osgi.service.component.annotations.Component;

import com.icfolson.aem.groovy.console.api.StarImportExtensionProvider;
import com.icfolson.aem.groovy.console.constants.GroovyConsoleConstants;

import de.valtech.aecu.api.groovy.console.bindings.filters.FilterBy;

@Component(immediate = true)
public class AecuStarImportExtensionProvider implements StarImportExtensionProvider {

    @Override
    public Set<String> getStarImports() {
        Set<String> imports = GroovyConsoleConstants.DEFAULT_STAR_IMPORTS;
        imports.add(FilterBy.class.getPackage().getName());
        return imports;
    }
}
